==> activity-center-biz-1.0.2-20160701.054452-45-sources.jar: cn/com/duiba/activity/center/biz/entity/game/DuibaQuestionAnswerOptionsEntity.java <==
package cn.com.duiba.activity.center.biz.entity.game;

import java.io.Serializable;
import java.util.Date;

/**
 * 此类在credits中原名QuestionAnswerOptionsDO
 */
public class DuibaQuestionAnswerOptionsEntity implements Serializable {
	private static final long serialVersionUID = -3830522519678060672L;
	private Long id;
	private Long duibaQuestionAnswerId;
	private Long itemId;
	private Integer payload;
	private String description;
	private String logo;
	private String name;
	private String prizeType;
	private Long facePrice;
	private Integer remaining;
	private Integer hidden;
	private Integer qualifyNum;
	private Boolean deleted;
	private Date gmtCreate;
	private Date gmtModified;

	/*奖项个数*/
	private Integer optionCount;
	/*新增奖项个数*/
	private Integer newOptionCount;

	public Integer getOptionCount() {
		return optionCount;
	}

	public void setOptionCount(Integer optionCount) {
		this.optionCount = optionCount;
	}

	public Integer getNewOptionCount() {
		return newOptionCount;
	}

	public void setNewOptionCount(Integer newOptionCount) {
		this.newOptionCount = newOptionCount;
	}

	public DuibaQuestionAnswerOptionsEntity() {}

	public DuibaQuestionAnswerOptionsEntity(Long id) {
		this.id = id;
	}

	public Long getFacePrice() {
		return facePrice;
	}
	public void setFacePrice(Long facePrice) {
		this.facePrice = facePrice;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getDuibaQuestionAnswerId() {
		return duibaQuestionAnswerId;
	}
	public void setDuibaQuestionAnswerId(Long duibaQuestionAnswerId) {
		this.duibaQuestionAnswerId = duibaQuestionAnswerId;
	}
	public Long getItemId() {
		return itemId;
	}
	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}
	public Integer getPayload() {
		return payload;
	}
	public void setPayload(Integer payload) {
		this.payload = payload;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getPrizeType() {
		return prizeType;
	}
	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}
	public Integer getRemaining() {
		return remaining;
	}
	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}
	public Integer getHidden() {
		return hidden;
	}
	public void setHidden(Integer hidden) {
		this.hidden = hidden;
	}
	public Integer getQualifyNum() {
		return qualifyNum;
	}
	public void setQualifyNum(Integer qualifyNum) {
		this.qualifyNum = qualifyNum;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
}

==> activity-center-biz-1.2.8.3-20161025.011418-1-sources.jar: cn/com/duiba/activity/center/biz/entity/game/DuibaQuestionAnswerOptionsEntity.java <==
package cn.com.duiba.activity.center.biz.entity.game;

import java.io.Serializable;
import java.util.Date;

/**
 * 此类在credits中原名QuestionAnswerOptionsDO
 */
public class DuibaQuestionAnswerOptionsEntity implements Serializable {
	private static final long serialVersionUID = -3830522519678060672L;
	private Long id;
	private Long duibaQuestionAnswerId;
	private Long itemId;
	private Integer payload;
	private String description;
	private String logo;
	private String name;
	private String prizeType;
	private Long facePrice;
	private Integer remaining;
	private Integer hidden;
	private Integer qualifyNum;
	private Boolean deleted;
	private Date gmtCreate;
	private Date gmtModified;

	/*奖项个数*/
	private Integer optionCount;
	/*新增奖项个数*/
	private Integer newOptionCount;
	
	private String itemName;//回调实物优惠券名称

	public Integer getOptionCount() {
		return optionCount;
	}

	public void setOptionCount(Integer optionCount) {
		this.optionCount = optionCount;
	}

	public Integer getNewOptionCount() {
		return newOptionCount;
	}

	public void setNewOptionCount(Integer newOptionCount) {
		this.newOptionCount = newOptionCount;
	}

	public DuibaQuestionAnswerOptionsEntity() {}

	public DuibaQuestionAnswerOptionsEntity(Long id) {
		this.id = id;
	}

	public Long getFacePrice() {
		return facePrice;
	}
	public void setFacePrice(Long facePrice) {
		this.facePrice = facePrice;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getDuibaQuestionAnswerId() {
		return duibaQuestionAnswerId;
	}
	public void setDuibaQuestionAnswerId(Long duibaQuestionAnswerId) {
		this.duibaQuestionAnswerId = duibaQuestionAnswerId;
	}
	public Long getItemId() {
		return itemId;
	}
	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}
	public Integer getPayload() {
		return payload;
	}
	public void setPayload(Integer payload) {
		this.payload = payload;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getPrizeType() {
		return prizeType;
	}
	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}
	public Integer getRemaining() {
		return remaining;
	}
	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}
	public Integer getHidden() {
		return hidden;
	}
	public void setHidden(Integer hidden) {
		this.hidden = hidden;
	}
	public Integer getQualifyNum() {
		return qualifyNum;
	}
	public void setQualifyNum(Integer qualifyNum) {
		this.qualifyNum = qualifyNum;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
    
    public String getItemName() {
        return itemName;
    }
    
    public void setItemName(String itemName) {
        this.itemName = itemName;
    }
}
